@@ -128,6 +128,9 @@ class FilenameDescription(FormatterBase):
     """
     # TODO : deal with CamelCaseFilenames
 
+    separators = ['_', '-'] # space substitute separators
+    lesser_words = [ 'or', 'a', 'the', 'on', 'of' ] # unimportant words
+
     def __call__(self, request, data):
         for f in data['files']:
             if f['description'] is None:
@@ -135,8 +138,11 @@ class FilenameDescription(FormatterBase):
                 if '.' in description:
                     description = description.rsplit('.', 1)[0]
                 decription = description.strip('_')
-                if '_' in description:
-                    description = ' '.join([i.title() for i in description.split('_')])
+                for separator in self.separators:
+                    if separator in description:
+                        description = ' '.join([(i in self.lesser_words) and i or i.title()
+                                                for i in description.split(separator)])
+                        description = description[0].upper() + description[1:]
                 f['description'] = description
 
 
