@@ -54,16 +54,25 @@ class Decoupage(object):
         self.fileserver = FileApp # XXX still used?!?
 
         # pluggable formats
+        s = 'decoupage.format.'
+        _format_args = [ (i.split(s, 1)[-1], j) for i, j in app_conf.items()
+                         if i.startswith(s) ]
+        format_args = {}
+        for i, j in _format_args:
+            assert i.count('.') == 1, 'Illegal string or something'
+            format_name, var_name = i.split('.')
+            format_args.setdefault(format_name, {})[var_name] = j
         self.formats = {}
         for _format in iter_entry_points('decoupage.formats'):
             try:
-                function = _format.load()
+                _cls = _format.load()
+                _instance = _cls(self, **format_args.get(_format.name, {}))
             except Exception, e:
                 # record the error, but persist
                 print >> sys.stderr, "Couldn't load format: %s" % _format
                 print >> sys.stderr, e
                 continue
-            self.formats[_format.name] = function
+            self.formats[_format.name] = _instance
         
         # pluggable index data formatters
         self.formatters = {}
@@ -133,6 +142,7 @@ class Decoupage(object):
         conf = self.conf(path)
 
         ### build data dictionary
+        # TODO: separate these out into several formatters
         files = self.filedata(path, directory, conf)
         data = {'path': path, 'files': files, 'request': request }
 
@@ -169,8 +179,8 @@ class Decoupage(object):
         if 'format' in request.GET:
             format_name = request.GET['format']
             if format_name in self.formats:
-                function = self.formats[format_name]
-                content_type, body = function(data)
+                _format = self.formats[format_name]
+                content_type, body = _format(request, data)
                 return Response(content_type=content_type, body=body)
 
         # render the template
@@ -208,23 +218,38 @@ class Decoupage(object):
 
     ### internal methods
 
-    def filedata(self, path, directory, conf):
+    def filedata(self, path, directory, conf=None):
+        conf = conf or {}
         files = []
 
-        for i in os.listdir(directory):
+        # get data for files
+        filenames = os.listdir(directory)
+        for i in filenames:
             filepath = os.path.join(directory, i)
             filetype = 'file'
             if os.path.isdir(filepath):
                 filetype = 'directory'
             modified = os.path.getmtime(filepath)
             modified = datetime.fromtimestamp(modified)
-            files.append({'path' : '%s/%s' % (path.rstrip('/'), i),
-                          'name': i,
-                          'modified': modified,
-                          'description': conf.get(i.lower(), None),
-                          'type': filetype})
+            data = {'path' : '%s/%s' % (path.rstrip('/'), i),
+                    'name': i,
+                    'modified': modified,
+                    'type': filetype}
+            if filetype == 'file':
+                data['size'] =  os.path.getsize(filepath)
+            files.append(data)
         
         # TODO: deal with other links in conf
+        for i in conf:
+            if i in filenames or i.startswith('/'):
+                continue
+            if i.startswith('http://') or i.startswith('https://'):
+                files.append({'path': i,
+                              'name': i,
+                              'type': link})
+            
+        for f in files:
+            f['description'] = conf.get(f['name'].lower(), None)
 
         return files
 
